import requests

MI_HOUSE_ANALYSIS_PDF_FILE_URL = "https://www.legislature.mi.gov/documents/2023-2024/billanalysis/house/pdf/"
MI_SENATE_ANALYSIS_PDF_FILE_URL = "https://www.legislature.mi.gov/documents/2023-2024/billanalysis/senate/pdf/"